/* UsiFe FileSystem
----------------
Copyright (2012): Rohan Sharma and Saurabh Kumar

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

CONTACT: 
Rohan Sharma : rickyrohan14@gmail.com
Saurabh Kumar : saurabh.catch@gmail.com
Smruti R. Sarangi : srsarangi@cse.iitd.ac.in
*/

package com.example;

import javax.swing.JOptionPane;
import javax.swing.JDialog;
import javax.swing.JButton;
import javax.swing.JRadioButton;
import javax.swing.ButtonGroup;
import javax.swing.JLabel;
import javax.swing.ImageIcon;
import javax.swing.BoxLayout;
import javax.swing.Box;
import javax.swing.BorderFactory;
import javax.swing.border.Border;
import javax.swing.JTabbedPane;
import javax.swing.JPanel;
import javax.swing.JFrame;
import java.beans.*; //Property change stuff
import java.awt.*;
import java.awt.event.*;
import java.util.StringTokenizer; 

/*
 * DialogDemo.java requires these files:
 *   
 *   images/middle.gif
 */
public class DialogDemo extends JPanel {
    JLabel label;
    ImageIcon icon = createImageIcon("images/middle.gif");
    JFrame frame;
    String simpleDialogDesc = "Customize privilege levels";
    String iconDesc = "Add pages to this privilege level";
    String moreDialogDesc = "Raise your privilege level";
    

    /** Creates the GUI shown inside the frame's content pane. */
    public DialogDemo(JFrame frame) {
        super(new BorderLayout());
        this.frame = frame;
        

        //Create the components.
        //JPanel frequentPanel = createSimpleDialogBox();
        JPanel featurePanel = createFeatureDialogBox();
        //JPanel encPanel = createEncDialogBox();
        JPanel frequentPanel = createFreqDialogBox();
        label = new JLabel("",
                           JLabel.CENTER);

        //Lay them out.
        Border padding = BorderFactory.createEmptyBorder(20,20,5,20);
        //frequentPanel.setBorder(padding);
        featurePanel.setBorder(padding);
        //encPanel.setBorder(padding);

        JTabbedPane tabbedPane = new JTabbedPane();
         //tooltip text
        tabbedPane.addTab("Privilege level", null,
                          featurePanel,
                          moreDialogDesc); //tooltip text
        //tabbedPane.addTab("Set encryption level", null, encPanel,iconDesc); //tooltip text

        tabbedPane.addTab("Settings", null,
                          frequentPanel,
                          simpleDialogDesc);


        add(tabbedPane, BorderLayout.CENTER);
        add(label, BorderLayout.PAGE_END);
        label.setBorder(BorderFactory.createEmptyBorder(10,10,10,10));
    }

    /** Sets the text displayed at the bottom of the frame. */
    void setLabel(String newText) {
        label.setText(newText);
    }

    /** Returns an ImageIcon, or null if the path was invalid. */
    protected static ImageIcon createImageIcon(String path) {
        java.net.URL imgURL = DialogDemo.class.getResource(path);
        if (imgURL != null) {
            return new ImageIcon(imgURL);
        } else {
            System.err.println("Couldn't find file: " + path);
            return null;
        }
    }

    /**
     * Used by createSimpleDialogBox and createFeatureDialogBox
     * to create a pane containing a description, a single column
     * of radio buttons, and the Show it! button.
     */
    private JPanel createPane(String description,
                              JRadioButton[] radioButtons,
                              JButton showButton) {

        int numChoices = radioButtons.length;
        JPanel box = new JPanel();
        JLabel label = new JLabel(description);

        box.setLayout(new BoxLayout(box, BoxLayout.PAGE_AXIS));
        box.add(label);

        for (int i = 0; i < numChoices; i++) {
            box.add(radioButtons[i]);
        }

        JPanel pane = new JPanel(new BorderLayout());
        pane.add(box, BorderLayout.PAGE_START);
        pane.add(showButton, BorderLayout.PAGE_END);
        return pane;
    }




    /** Creates the panel shown by the second tab. */
    private JPanel createFreqDialogBox() {
        final int numButtons = 7;
        JRadioButton[] radioButtons = new JRadioButton[numButtons];
        final ButtonGroup group = new ButtonGroup();

        JButton showItButton = null;

                String priLevelsData=UsifeNew.getUsifeData("PrivilegeLevels");
        StringTokenizer priLevels=new StringTokenizer(priLevelsData,":");

        final String HR = priLevels.nextToken();
        final String Technical = priLevels.nextToken();
        final String Manager = priLevels.nextToken();
        final String CL1 = priLevels.nextToken();
        final String CL2 = priLevels.nextToken();
        final String CL3 = priLevels.nextToken();
        final String CL4 = priLevels.nextToken();


        radioButtons[0] = new JRadioButton(HR);
        radioButtons[0].setActionCommand(HR);

        radioButtons[1] = new JRadioButton(Technical);
        radioButtons[1].setActionCommand(Technical);

        radioButtons[2] = new JRadioButton(Manager);
        radioButtons[2].setActionCommand(Manager);

        radioButtons[3] = new JRadioButton(CL1);
        radioButtons[3].setActionCommand(CL1);

        radioButtons[4] = new JRadioButton(CL2);
        radioButtons[4].setActionCommand(CL2);

        radioButtons[5] = new JRadioButton(CL3);
        radioButtons[5].setActionCommand(CL3);

        radioButtons[6] = new JRadioButton(CL4);
        radioButtons[6].setActionCommand(CL4);


        for (int i = 0; i < numButtons; i++) {
            group.add(radioButtons[i]);
        }
        radioButtons[0].setSelected(true);

        showItButton = new JButton("Proceed!");
        showItButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                String command = group.getSelection().getActionCommand();
                UsifeNew.reset();
                //pick one of many
                 if (command == HR) {
                    String s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                "Enter new label",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);
                    if(s1=="") {
                        s1=HR;
                    }

                    UsifeNew.setUsifeData("PrivilegeLevels",s1+":"+Technical+":"+Manager+":"+CL1+":"+CL2+":"+CL3+":"+CL4);
                    frame.setVisible(false);
                        return;


                //non-auto-closing dialog
                } else if (command == Technical) {
                    String s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                "Enter new label",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);
                    if(s1=="") {
                        s1=Technical;
                    }

                    UsifeNew.setUsifeData("PrivilegeLevels",HR+":"+s1+":"+Manager+":"+CL1+":"+CL2+":"+CL3+":"+CL4);
                    System.out.println("here"+UsifeNew.getUsifeData("PrivilegeLevels"));
                    frame.setVisible(false);
                        return;
                } else if (command == Manager) {
                    String s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                "Enter new label",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);

                    if(s1=="") {
                        s1=Manager;
                    }

                    UsifeNew.setUsifeData("PrivilegeLevels",HR+":"+Technical+":"+s1+":"+CL1+":"+CL2+":"+CL3+":"+CL4);

                    frame.setVisible(false);
                        return;
                } else if (command == CL1) {
                    String s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                "Enter new label",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);
                    if(s1=="") {
                        s1=CL1;
                    }

                    UsifeNew.setUsifeData("PrivilegeLevels",HR+":"+Technical+":"+Manager+":"+s1+":"+CL2+":"+CL3+":"+CL4);

                    frame.setVisible(false);
                        return;
                } else if (command == CL2) {
                    String s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                "Enter new label",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);

                    if(s1=="") {
                        s1=CL2;
                    }
                    UsifeNew.setUsifeData("PrivilegeLevels",HR+":"+Technical+":"+Manager+":"+CL1+":"+s1+":"+CL3+":"+CL4);

                    frame.setVisible(false);
                        return;
                } else if (command == CL3) {
                    String s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                "Enter new label",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);

                    if(s1=="") {
                        s1=CL3;
                    }
                    UsifeNew.setUsifeData("PrivilegeLevels",HR+":"+Technical+":"+Manager+":"+CL1+":"+CL2+":"+s1+":"+CL4);

                    frame.setVisible(false);
                        return;
                } else if (command == CL4) {
                    String s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                "Enter new label",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);

                    if(s1=="") {
                        s1=CL4;
                    }
                    UsifeNew.setUsifeData("PrivilegeLevels",HR+":"+Technical+":"+Manager+":"+CL1+":"+CL2+":"+CL3+":"+s1);

                    frame.setVisible(false);
                        return;
                }
            }
        });

        return createPane(simpleDialogDesc + ":",
                          radioButtons,
                          showItButton);
    }

    /** Creates the panel shown by the second tab. */
    private JPanel createFeatureDialogBox() {
        final int numButtons = 7;
        JRadioButton[] radioButtons = new JRadioButton[numButtons];
        final ButtonGroup group = new ButtonGroup();

        JButton showItButton = null;

        UsifeNew.reset();

        String priLevelsData=UsifeNew.getUsifeData("PrivilegeLevels");
        System.out.println(priLevelsData);
        StringTokenizer priLevels=new StringTokenizer(priLevelsData,":");

        final String HR = priLevels.nextToken();
        final String Technical = priLevels.nextToken();
        final String Manager = priLevels.nextToken();
        final String CL1 = priLevels.nextToken();
        final String CL2 = priLevels.nextToken();
        final String CL3 = priLevels.nextToken();
        final String CL4 = priLevels.nextToken();


        radioButtons[0] = new JRadioButton(HR);
        radioButtons[0].setActionCommand(HR);

        radioButtons[1] = new JRadioButton(Technical);
        radioButtons[1].setActionCommand(Technical);

        radioButtons[2] = new JRadioButton(Manager);
        radioButtons[2].setActionCommand(Manager);

        radioButtons[3] = new JRadioButton(CL1);
        radioButtons[3].setActionCommand(CL1);

        radioButtons[4] = new JRadioButton(CL2);
        radioButtons[4].setActionCommand(CL2);

        radioButtons[5] = new JRadioButton(CL3);
        radioButtons[5].setActionCommand(CL3);

        radioButtons[6] = new JRadioButton(CL4);
        radioButtons[6].setActionCommand(CL4);



        for (int i = 0; i < numButtons; i++) {
            group.add(radioButtons[i]);
        }
        radioButtons[0].setSelected(true);

        showItButton = new JButton("Proceed!");
        showItButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                String command = group.getSelection().getActionCommand();
                UsifeNew.reset();
                //pick one of many
                String usifeData=UsifeNew.getUsifeData("UsifeData");
                    StringTokenizer st = new StringTokenizer(usifeData, ";");
                    String tmp1;
                    if(st.hasMoreTokens()) {
                        tmp1=st.nextToken();
                    } else{
                         tmp1=" ";
                     }
                    String tmp2;
                    if(st.hasMoreTokens()) {
                        tmp2=st.nextToken();
                    } else{
                         tmp2=" ";
                     }

                    String tmp3;
                    if(st.hasMoreTokens()) {
                        tmp3=st.nextToken();
                    } else{
                         tmp3=" ";
                     }

                String tmp4;
                    if(st.hasMoreTokens()) {
                        tmp4=st.nextToken();
                    } else{
                         tmp4=" ";
                     }
                String tmp5;
                    if(st.hasMoreTokens()) {
                        tmp5=st.nextToken();
                    } else{
                         tmp5=" ";
                     }

                String tmp6;
                    if(st.hasMoreTokens()) {
                        tmp6=st.nextToken();
                    } else{
                         tmp6=" ";
                     }

               String tmp7;
                    if(st.hasMoreTokens()) {
                        tmp7=st.nextToken();
                    } else{
                         tmp7=" ";
                     }


                 if (command == HR) {

                    
                   String s = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                      if(s==null)
                          return;

                            StringTokenizer st1 = new StringTokenizer(tmp1, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s);
                                    UsifeNew.decryptPage(tmp, s);
                                    UsifeNew.unHidePage(tmp);
                                }
                            } catch (Exception ex) {
                                //error=1;
                                //continue;
                                return;
                            }



                    
                        return;


                //non-auto-closing dialog
                } else if (command == Technical) {
                    
                   String s = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                      if(s==null)
                          return;

                            StringTokenizer st1 = new StringTokenizer(tmp2, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s);
                                    UsifeNew.decryptPage(tmp, s);
                                    UsifeNew.unHidePage(tmp);
                                }
                            } catch (Exception ex) {
                                //error=1;
                                //continue;
                                return;
                            }


                        return;
                } else if (command == Manager) {
                    
                   String s = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                      if(s==null)
                          return;

                            StringTokenizer st1 = new StringTokenizer(tmp3, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s);
                                    UsifeNew.decryptPage(tmp, s);
                                    UsifeNew.unHidePage(tmp);
                                }
                            } catch (Exception ex) {
                                //error=1;
                                //continue;
                                return;
                            }


                        return;
                }  else if (command == CL1) {

                   String s = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                      if(s==null)
                          return;

                            StringTokenizer st1 = new StringTokenizer(tmp4, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s);
                                    UsifeNew.decryptPage(tmp, s);
                                    UsifeNew.unHidePage(tmp);
                                }
                            } catch (Exception ex) {
                                //error=1;
                                //continue;
                                return;
                            }


                        return;
                }  else if (command == CL2) {

                   String s = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                      if(s==null)
                          return;

                            StringTokenizer st1 = new StringTokenizer(tmp5, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s);
                                    UsifeNew.decryptPage(tmp, s);
                                    UsifeNew.unHidePage(tmp);
                                }
                            } catch (Exception ex) {
                                //error=1;
                                //continue;
                                return;
                            }


                        return;
                }  else if (command == CL3) {

                   String s = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                      if(s==null)
                          return;

                            StringTokenizer st1 = new StringTokenizer(tmp6, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s);
                                    UsifeNew.decryptPage(tmp, s);
                                    UsifeNew.unHidePage(tmp);
                                }
                            } catch (Exception ex) {
                                //error=1;
                                //continue;
                                return;
                            }


                        return;
                }  else if (command == CL4) {

                   String s = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                      if(s==null)
                          return;

                            StringTokenizer st1 = new StringTokenizer(tmp7, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s);
                                    UsifeNew.decryptPage(tmp, s);
                                    UsifeNew.unHidePage(tmp);
                                }
                            } catch (Exception ex) {
                                //error=1;
                                //continue;
                                return;
                            }


                        return;
                }
            }
        });

        return createPane(moreDialogDesc + ":",
                          radioButtons,
                          showItButton);
    }
/*
/** Creates the panel shown by the second tab. 
    private JPanel createEncDialogBox() {
        final int numButtons = 7;
        JRadioButton[] radioButtons = new JRadioButton[numButtons];
        final ButtonGroup group = new ButtonGroup();

        JButton showItButton = null;


        String priLevelsData=UsifeNew.getUsifeData("PrivilegeLevels");
        StringTokenizer priLevels=new StringTokenizer(priLevelsData,":");

        final String HR = priLevels.nextToken();
        final String Technical = priLevels.nextToken();
        final String Manager = priLevels.nextToken();
        final String CL1 = priLevels.nextToken();
        final String CL2 = priLevels.nextToken();
        final String CL3 = priLevels.nextToken();
        final String CL4 = priLevels.nextToken();


        radioButtons[0] = new JRadioButton(HR);
        radioButtons[0].setActionCommand(HR);

        radioButtons[1] = new JRadioButton(Technical);
        radioButtons[1].setActionCommand(Technical);

        radioButtons[2] = new JRadioButton(Manager);
        radioButtons[2].setActionCommand(Manager);

        radioButtons[3] = new JRadioButton(CL1);
        radioButtons[3].setActionCommand(CL1);

        radioButtons[4] = new JRadioButton(CL2);
        radioButtons[4].setActionCommand(CL2);

        radioButtons[5] = new JRadioButton(CL3);
        radioButtons[5].setActionCommand(CL3);

        radioButtons[6] = new JRadioButton(CL4);
        radioButtons[6].setActionCommand(CL4);

        for (int i = 0; i < numButtons; i++) {
            group.add(radioButtons[i]);
        }
        radioButtons[0].setSelected(true);

        showItButton = new JButton("Add new pages to this privilege level");
        showItButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent e) {
                String command = group.getSelection().getActionCommand();

                UsifeNew.reset();
                                String usifeData=UsifeNew.getUsifeData("UsifeData");
                    StringTokenizer st = new StringTokenizer(usifeData, ";");
                    String tmp1;
                    if(st.hasMoreTokens()) {
                        tmp1=st.nextToken();
                    } else{
                         tmp1="";
                     }
                    String tmp2;
                    if(st.hasMoreTokens()) {
                        tmp2=st.nextToken();
                    } else{
                         tmp2="";
                     }

                    String tmp3;
                    if(st.hasMoreTokens()) {
                        tmp3=st.nextToken();
                    } else{
                         tmp3="";
                     }

                String tmp4;
                    if(st.hasMoreTokens()) {
                        tmp4=st.nextToken();
                    } else{
                         tmp4="";
                     }
                String tmp5;
                    if(st.hasMoreTokens()) {
                        tmp5=st.nextToken();
                    } else{
                         tmp5="";
                     }

                String tmp6;
                    if(st.hasMoreTokens()) {
                        tmp6=st.nextToken();
                    } else{
                         tmp6="";
                     }

               String tmp7;
                    if(st.hasMoreTokens()) {
                        tmp7=st.nextToken();
                    } else{
                         tmp7="";
                     }

                   String s1,s2;
                    int error=0;
                     while(true) {
                              s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                error==0?"Enter comma separated list of pages (Current list:"+usifeData+")":"Error in input try again! \nEnter comma separated list of pages",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);


                             if(s1==null)
                                 break;

                             s2 = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                             if(s2==null)
                                 break;

                            StringTokenizer st1 = new StringTokenizer(s1, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s2);
                                    UsifeNew.encryptPage(tmp, s2);
                                }
                            } catch (Exception ex) {
                                error=1;
                                continue;
                            }
                        st1 = new StringTokenizer(s1, ",");
                    while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    UsifeNew.hidePage(tmp);
                                }



                 if (command == HR) {
                    String s1,s2;
                    int error=0;
                     while(true) {
                              s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                error==0?"Enter comma separated list of pages (Current list:"+usifeData+")":"Error in input try again! \nEnter comma separated list of pages",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);


                             if(s1==null)
                                 break;

                             s2 = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                             if(s2==null)
                                 break;

                            StringTokenizer st1 = new StringTokenizer(s1, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s2);
                                    UsifeNew.encryptPage(tmp, s2);
                                }
                            } catch (Exception ex) {
                                error=1;
                                continue;
                            }
                        st1 = new StringTokenizer(s1, ",");
                            while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    UsifeNew.hidePage(tmp);
                                }
                        
                      if(s1!=null) {
                        UsifeNew.setUsifeData("UsifeData",((!tmp1.equals(" "))?(tmp1+","+s1):s1)+";"+tmp2+";"+tmp3+";"+tmp4+";"+tmp5+";"+tmp6+";"+tmp7);
                        UsifeNew.save();
                     }
                        break;
                     }
                     


                  

                        return;


                //non-auto-closing dialog
                } else if (command == Technical) {
                    
                    String s1,s2;
                    int error=0;
                     while(true) {
                              s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                error==0?"Enter comma separated list of pages (Current list:"+usifeData+")":"Error in input try again! \nEnter comma separated list of pages",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);


                             if(s1==null)
                                 break;

                             s2 = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                             if(s2==null)
                                 break;

                            StringTokenizer st1 = new StringTokenizer(s1, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s2);
                                    UsifeNew.encryptPage(tmp, s2);
                                }
                            } catch (Exception ex) {
                                error=1;
                                System.out.println("exception");
                                continue;
                            }
                    st1 = new StringTokenizer(s1, ",");
                        while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    UsifeNew.hidePage(tmp);
                                }

                         if(s1!=null) {
                             System.out.println("a"+tmp2+"b");
                            UsifeNew.setUsifeData("UsifeData",tmp1+";"+((!tmp2.equals(" "))?(tmp2+","+s1):s1)+";"+tmp3+";"+tmp4+";"+tmp5+";"+tmp6+";"+tmp7);
                            UsifeNew.save();
                         }
                            break;
                     }
                     return;
                } else if (command == Manager) {
                       String s1,s2;
                    int error=0;
                     while(true) {
                              s1 = (String)JOptionPane.showInputDialog(
                                                frame,
                                                error==0?"Enter comma separated list of pages (Current list:"+usifeData+")":"Error in input try again! \nEnter comma separated list of pages",
                                                "pages",
                                                JOptionPane.PLAIN_MESSAGE,
                                                icon,
                                                null,
                                                null);


                             if(s1==null)
                                 break;

                             s2 = (String)JOptionPane.showInputDialog(
                                        frame,
                                        "Enter Key",
                                        "Key",
                                        JOptionPane.PLAIN_MESSAGE,
                                        icon,
                                        null,
                                        null);

                             if(s2==null)
                                 break;

                            StringTokenizer st1 = new StringTokenizer(s1, ",");
                            try {
                                while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    System.out.println("Encrypting page "+tmp+" key "+s2);
                                    UsifeNew.encryptPage(tmp, s2);
                                }
                            } catch (Exception ex) {
                                error=1;
                                continue;
                            }
                        st1 = new StringTokenizer(s1, ",");
                    while(st1.hasMoreTokens()) {
                                    int tmp=Integer.parseInt(st1.nextToken());
                                    UsifeNew.hidePage(tmp);
                                }
                         if(s1!=null) {
                            UsifeNew.setUsifeData("UsifeData",tmp1+";"+tmp2+";"+((!tmp3.equals(" "))?(tmp3+","+s1):s1)+";"+tmp4+";"+tmp5+";"+tmp6+";"+tmp7);
                            UsifeNew.save();
                         }
                            break;
                     }
                     return;
                } else if (command == CL1 ) {
    
                         if(s1!=null) {
                            UsifeNew.setUsifeData("UsifeData",tmp1+";"+tmp2+";"+tmp3+";"+((!tmp4.equals(" "))?(tmp4+","+s1):s1)+";"+tmp5+";"+tmp6+";"+tmp7);
                            UsifeNew.save();
                         }
                            break;
                     }
                     return;
                }
            }
        });

        return createPane(iconDesc + ":",
                          radioButtons,
                          showItButton);
    }


*/

    /**
     * Create the GUI and show it.  For thread safety,
     * this method should be invoked from the
     * event-dispatching thread.
     */
    private static void createAndShowGUI() {
        //Create and set up the window.
        JFrame frame = new JFrame("");
        //frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        //Create and set up the content pane.
        DialogDemo newContentPane = new DialogDemo(frame);
        newContentPane.setOpaque(true); //content panes must be opaque
        frame.setContentPane(newContentPane);

        //Display the window.
        frame.pack();
        frame.setVisible(true);
    }

    public static void StartDialog() {
        //Schedule a job for the event-dispatching thread:
        //creating and showing this application's GUI.
        javax.swing.SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                createAndShowGUI();
            }
        });
    }

}

